Skip to contents

BaranyiRM function to fit the Baranyi and Roberts growth model to a reduced microbial growth curve. Returns the model parameters estimated according to data collected in microbial growth experiments.

Usage

BaranyiRM(t, Y0, MUmax, lag)

Arguments

t

is a numeric vector indicating the time of the experiment

Y0

is the natural logarithm of the initial microbial concentration (ln(N0)) at time=0

MUmax

is the maximum specific growth rate given in time units

lag

is the duration of the lag phase in time units

Value

A numeric vector with the fitted values

Details

Model's inputs are:

t: time, assuming time zero as the beginning of the experiment.

Y(t): the natural logarithm of the microbial concentration (ln(N(t))) measured at time t.

Users should make sure that the microbial concentration input is entered in natural logarithm, Y(t) = ln(N(t)).

References

Baranyi J, Roberts TA (1995). “Mathematics of predictive microbiology.” International Journal of Food Microbiology, 26, 199-218.

Author

Vasco Cadavez, vcadavez@ipb.pt and Ursula Gonzales-Barron, ubarron@ipb.pt

Examples

## Example: Baranyi reduced model
library(gslnls)
data(growthred) # simulated data set.
initial_values <- list(Y0 = 0.1, MUmax = 1.7, lag = 5) # define the initial values
fit <- gsl_nls(lnN ~ BaranyiRM(Time, Y0, MUmax, lag),
  data = growthred,
  start = initial_values
)
summary(fit)
#> 
#> Formula: lnN ~ BaranyiRM(Time, Y0, MUmax, lag)
#> 
#> Parameters:
#>       Estimate Std. Error t value Pr(>|t|)    
#> Y0    -0.01690    0.24928  -0.068    0.948    
#> MUmax  1.84523    0.05189  35.560 3.30e-08 ***
#> lag    5.03644    0.25349  19.869 1.05e-06 ***
#> ---
#> Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#> 
#> Residual standard error: 0.4117 on 6 degrees of freedom
#> 
#> Number of iterations to convergence: 8 
#> Achieved convergence tolerance: 2.22e-16
#>