Skip to contents

BuchananRM function to fit the Buchanan reduced growth model to a reduced microbial growth curve. Returns the model parameters estimated according to data collected in microbial growth experiments.

Usage

BuchananRM(t, Y0, MUmax, lag)

Arguments

t

is a numeric vector indicating the time of the experiment

Y0

is the natural logarithm of the initial microbial concentration (ln(N0)) at time=0

MUmax

is the maximum specific growth rate given in time units

lag

is the duration of the lag phase in time units

Value

A numeric vector with the fitted values

Details

Model's inputs are:

t: time, assuming time zero as the beginning of the experiment.

Y(t): the natural logarithm of the microbial concentration (ln(N(t))) measured at time t.

Users should make sure that the microbial concentration input is entered in natural logarithm, Y(t) = ln(N(t)).

References

Buchanan RL, Whiting RC, Damert WC (1997). “When is simple good enough: a comparison of the Gompertz, Baranyi, and three-phase linear models for fitting bacterial growth curves.” Food Microbiology, 14(4), 313-326. ISSN 0740-0020, doi:10.1006/fmic.1997.0125 .

Author

Vasco Cadavez, vcadavez@ipb.pt and Ursula Gonzales-Barron, ubarron@ipb.pt

Examples

## Example: Buchanan reduced model
library(gslnls)
data(growthred) # simulated data set.
initial_values <- list(Y0 = 0, MUmax = 1.7, lag = 5) # define the initial values
fit <- gsl_nls(lnN ~ BuchananRM(Time, Y0, MUmax, lag),
  data = growthred,
  start = initial_values
)
summary(fit)
#> 
#> Formula: lnN ~ BuchananRM(Time, Y0, MUmax, lag)
#> 
#> Parameters:
#>       Estimate Std. Error t value Pr(>|t|)    
#> Y0     0.05010    0.22810    0.22    0.833    
#> MUmax  1.83840    0.04722   38.93 1.92e-08 ***
#> lag    5.04160    0.21567   23.38 4.02e-07 ***
#> ---
#> Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#> 
#> Residual standard error: 0.3951 on 6 degrees of freedom
#> 
#> Number of iterations to convergence: 4 
#> Achieved convergence tolerance: 2.22e-15
#>