CMAW function to fit the water activity cardinal model (Rosso et al., 1993).
Returns the model parameters estimated according to data collected in microbial growth experiments.
Details
The model's inputs are:
x: Water activity
sqrtGR: the square root of the growth rate (\(h^{-1}\))
Users should make sure that the growth rate input is entered after a square root transformation, sqrGR = sqrt(GR).
References
Rosso L, Lobry J, Charles (Bajard) S, Flandrois J (1995). “Convenient Model To Describe the Combined Effects of Temperature and pH on Microbial Growth.” Applied and environmental microbiology, 61, 610–6. doi:10.1128/AEM.61.2.610-616.1995 .
Author
Vasco Cadavez vcadavez@ipb.pt and Ursula Gonzales-Barron ubarron@ipb.pt
Examples
library(gslnls)
data(aw)
initial_values <- list(AWmin = 0.89, MUopt = 1.0, AWopt = 0.98)
fit <- gsl_nls(sqrtGR ~ CMAW(aw, AWmin, MUopt, AWopt),
data = aw,
start = initial_values
)
summary(fit)
#>
#> Formula: sqrtGR ~ CMAW(aw, AWmin, MUopt, AWopt)
#>
#> Parameters:
#> Estimate Std. Error t value Pr(>|t|)
#> AWmin 0.771652 0.005203 148.30 6.34e-12 ***
#> MUopt 1.558631 0.060203 25.89 2.19e-07 ***
#> AWopt 0.946016 0.002955 320.16 6.27e-14 ***
#> ---
#> Signif. codes: 0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#>
#> Residual standard error: 0.04824 on 6 degrees of freedom
#>
#> Number of iterations to convergence: 9
#> Achieved convergence tolerance: 4.337e-16
#>