RossoFM function to fit the Rosso full growth model to complete microbial growth curve.
Returns the model parameters estimated according to data collected in microbial growth experiments.
Arguments
- t
is a numeric vector indicating the time of the experiment
- Y0
is the natural logarithm of the initial microbial concentration (
ln(N0)) at time=0- Ymax
is the natural logarithm of the maximum concentration (
ln(Nmax)) reached by the microorganism- MUmax
is the maximum specific growth rate given in time units
- lag
is the duration of the lag phase in time units
Details
Model's inputs are:
t: time, assuming time zero as the beginning of the experiment.
Y(t): the natural logarithm of the microbial concentration (ln(N(t))) measured at time t.
Users should make sure that the microbial concentration input is entered in natural logarithm, Y(t) = ln(X(t)).
References
Rosso L, Bajard S, Flandrois JP, Lahellec C, Fournaud J, Veit P (1996). “Differential growth of Listeria monocytogenes at 4 and 8 ºC: Consequences for the Shelf Life of Chilled Products.” Journal of Food Protection, 59(9), 944-949. ISSN 0362-028X, doi:10.4315/0362-028X-59.9.944 .
Author
Vasco Cadavez (vcadavez@ipb.pt) and Ursula Gonzales-Barron (ubarron@ipb.pt)
Examples
## Example: Rosso full model
library(gslnls)
data(growthfull) # simulated data set.
initial_values <- list(Y0 = 0.04, Ymax = 21, MUmax = 1.9, lag = 5.0) # define the initial values
fit <- gsl_nls(lnN ~ RossoFM(Time, Y0, Ymax, MUmax, lag),
data = growthfull,
start = initial_values
)
summary(fit)
#>
#> Formula: lnN ~ RossoFM(Time, Y0, Ymax, MUmax, lag)
#>
#> Parameters:
#> Estimate Std. Error t value Pr(>|t|)
#> Y0 0.0501 0.2562 0.196 0.849
#> Ymax 21.1323 0.2237 94.485 8.45e-15 ***
#> MUmax 1.8592 0.0600 30.989 1.86e-10 ***
#> lag 5.0812 0.2447 20.761 6.53e-09 ***
#> ---
#> Signif. codes: 0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#>
#> Residual standard error: 0.4438 on 9 degrees of freedom
#>
#> Number of iterations to convergence: 10
#> Achieved convergence tolerance: 1.332e-15
#>