bias_factor() and accuracy_factor() calculate the multiplicative model
bias and accuracy factors commonly used in predictive microbiology model
validation.
bias_factor() and accuracy_factor() calculate the multiplicative model
bias and accuracy factors commonly used in predictive microbiology model
validation.