HuangRM function to fit the Huang reduced growth model to a reduced microbial growth curve.
Returns the model parameters estimated according to data collected in microbial growth experiments.
Details
Model's inputs are:
t: time, assuming time zero as the beginning of the experiment.
Y(t): the natural logarithm of the microbial concentration (ln(N(t))) measured at time t.
Users should make sure that the microbial concentration input is entered in natural logarithm, Y(t) = ln(N(t)).
References
Huang L (2008). “Growth Kinetics of Listeria monocytogenes in Broth and Beef Frankfurters-Determination of Lag Phase Duration and Exponential Growth Rate under Isothermal Conditions.” Journal of Food Science, 73(5), E235-E242. doi:10.1111/j.1750-3841.2008.00785.x .
Author
Vasco Cadavez, vcadavez@ipb.pt & Ursula Gonzales-Barron, ubarron@ipb.pt
Examples
## Example: Huang reduced model
library(gslnls)
data(growthred) # simulated data set.
initial_values <- list(Y0 = 0, MUmax = 1.7, lag = 5) # define the initial values
fit <- gsl_nls(lnN ~ HuangRM(Time, Y0, MUmax, lag),
data = growthred,
start = initial_values
)
summary(fit)
#>
#> Formula: lnN ~ HuangRM(Time, Y0, MUmax, lag)
#>
#> Parameters:
#> Estimate Std. Error t value Pr(>|t|)
#> Y0 0.04513 0.22979 0.196 0.851
#> MUmax 1.83842 0.04777 38.485 2.06e-08 ***
#> lag 5.03914 0.22005 22.900 4.54e-07 ***
#> ---
#> Signif. codes: 0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#>
#> Residual standard error: 0.3959 on 6 degrees of freedom
#>
#> Number of iterations to convergence: 7
#> Achieved convergence tolerance: 0
#>