dynamic_profile() stores time-varying environmental conditions such as
temperature, pH, or water activity for dynamic predictive microbiology
simulations. The profile is interpolated internally when dynamic models are
solved between observed profile points.
Usage
dynamic_profile(time, temperature = NULL, ph = NULL, aw = NULL, ...)
Arguments
- time
Numeric vector with profile times.
- temperature
Optional numeric vector with temperatures at time.
- ph
Optional numeric vector with pH values at time.
- aw
Optional numeric vector with water activity values at time.
- ...
Additional named numeric vectors with the same length as time.
Value
A predmicror_dynamic_profile data frame sorted by time.
Examples
profile <- dynamic_profile(
time = c(0, 5, 10, 15),
temperature = c(10, 4, 12, 20)
)
profile
#> Dynamic environmental profile
#> points: 4
#> time range: [0, 15]
#> variables: temperature
#> time temperature
#> 1 0 10
#> 2 5 4
#> 3 10 12
#> 4 15 20