Skip to contents

omnibus_secondary() defines a secondary model specification that can be used inside fit_omnibus(), fit_omnibus_growth(), or fit_omnibus_inactivation(). It allows a primary-model parameter to be described by another parameterised model already available in predmicror.

Usage

omnibus_secondary(model, x, transform = c("identity", "square"))

Arguments

model

Character string naming a registered predmicror model, for example "CMTI", "CMAW", "CMPH", or "CMInh".

x

Character string naming the covariate column used by the secondary model.

transform

Character string. One of "identity" or "square".

Value

An omnibus_secondary specification.

Examples

omnibus_secondary("CMTI", x = "Temp")
#> $model
#> [1] "CMTI"
#> 
#> $fun
#> [1] "CMTI"
#> 
#> $x
#> [1] "Temp"
#> 
#> $params
#> [1] "Tmax"  "Tmin"  "MUopt" "Topt" 
#> 
#> $response_scale
#> [1] "sqrtGR"
#> 
#> $transform
#> [1] "identity"
#> 
#> attr(,"class")
#> [1] "omnibus_secondary"
omnibus_secondary("CMTI", x = "Temp", transform = "square")
#> $model
#> [1] "CMTI"
#> 
#> $fun
#> [1] "CMTI"
#> 
#> $x
#> [1] "Temp"
#> 
#> $params
#> [1] "Tmax"  "Tmin"  "MUopt" "Topt" 
#> 
#> $response_scale
#> [1] "sqrtGR"
#> 
#> $transform
#> [1] "square"
#> 
#> attr(,"class")
#> [1] "omnibus_secondary"